package cn.com.ty.lift.quan.news.controller;

import cn.com.ty.lift.quan.news.dao.entity.QuanNews;
import cn.com.ty.lift.quan.news.service.impl.QuanNewsServiceImpl;
import cn.com.xwy.boot.web.dto.RestResponse;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.mysql.cj.jdbc.Blob;
import lombok.AllArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.sql.rowset.serial.SerialBlob;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.sql.SQLException;


/**
 * <p>
 * 电梯圈新闻公告 前端控制器
 * </p>
 *
 * @author wang-hai-cheng
 * @since 2019-12-02
 */
@RestController
@AllArgsConstructor
@RequestMapping("/quan-news")
public class QuanNewsController {
    private final QuanNewsServiceImpl quanNewsService;

    @GetMapping("/list")
    /**
     * @description 分页展示新闻公告
     * @date 2019/12/2 15:39
     * @param [页码, 页大小]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse list(@RequestParam int pageNum, @RequestParam int pageSize) {
        Page<QuanNews> page = new Page<>(pageNum, pageSize);
        IPage<QuanNews> top_serial = quanNewsService.page(page, new QueryWrapper<QuanNews>().eq("top_serial", "0"));
        if (!top_serial.getRecords().isEmpty()) {
            return RestResponse.ok(top_serial, "1", "查询成功");
        } else {
            return RestResponse.ok(null, "9", "无数据");
        }
    }

    @GetMapping("/top")
    /**
     * @description 置顶
     * @date 2019/12/2 15:40
     * @param [id]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse top(@RequestParam int id) {
        return quanNewsService.top(id);
    }

    @GetMapping("/{id}")
    /**
     * @description 根据id获取新闻
     * @date 2019/12/2 15:48
     * @param [id]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse news(@PathVariable int id) {
        QuanNews byId = quanNewsService.getById(id);
        if (null != byId) {
            return RestResponse.ok(byId, "1", "查询成功");
        } else {
            return RestResponse.ok(null, "9", "无数据");
        }
    }

    @GetMapping("/top1")
    /**
     * @description 获取置顶新闻
     * @date 2019/12/2 15:48
     * @param [id]
     * @return cn.com.ty.lift.quan.news.dao.entity.News
     */
    public RestResponse top1(@RequestParam int id) {
        QuanNews one = quanNewsService.getOne(new QueryWrapper<QuanNews>().eq("top_serial", 1));
        if (null != one) {
            return RestResponse.ok(one, "1", "查询成功");
        } else {
            return RestResponse.ok(null, "9", "无数据");
        }
    }

    @PostMapping("/add")
    /**
     * @description 新增新闻
     * @date 2019/12/2 15:48
     * @param [title, content, videoFile, releaseId]
     * @return org.springframework.http.ResponseEntity
     */
    public RestResponse add(@RequestParam String title, @RequestParam String content, @RequestParam MultipartFile videoFile, @RequestParam Long releaseId) throws Exception {
        QuanNews news = new QuanNews();
        SerialBlob blob = new SerialBlob(content.getBytes("UTF8"));
        news.setTitle(title).setContent(blob).setReleaseId(releaseId);
        System.out.println("视频名称:" + videoFile.getOriginalFilename());
        FileOutputStream fos;
        fos = new FileOutputStream("c:/" + videoFile.getOriginalFilename());
        fos.write(videoFile.getBytes());
        fos.close();
        return RestResponse.ok(null,"1","新增成功");
    }

//    @PostMapping("/add/top")
//    @ApiOperation("新增置顶新闻")
//    public ResponseEntity addTop() {
//
//    }

//    @GetMapping("/top/up")
//    @ApiOperation("置顶上移")
//    @GetMapping("/top/down")
//    @ApiOperation("置顶下移")

    @PostMapping("/update")
    /**
     * @description 根据id更新新闻信息
     * @date 2019/12/2 15:49
     * @param [新闻id, 新闻标题, 新闻内容]
     * @return org.springframework.http.ResponseEntity
     */
    public RestResponse updateNews(@RequestParam int id, @RequestParam String title, @RequestParam Blob content) {
        return quanNewsService.updateNews(id, title, content);
    }

    @PostMapping("/delete")
    /**
     * @description 根据id删除新闻
     * @date 2019/12/2 15:49
     * @param [id]
     * @return org.springframework.http.ResponseEntity
     */
    public RestResponse delete(@RequestParam int id) {
        if (quanNewsService.removeById(id)) {
            return RestResponse.ok(null, "0", "删除失败");
        } else {
            return RestResponse.ok(null, "1", "删除成功");
        }
    }
}